@@ -57,7 +57,7 @@ class GSPeerConnectionWatcher:
             self.logger.info("joined")
 
         @self.sio.event
-        async def broadcaster():
+        async def broadcaster(id):
             if len(self.rtconfiList) > 0:
                 self.peerConnections = RTCPeerConnection(configuration=RTCConfiguration(self.rtconfiList))
             else:
